@@ -1,7 +1,7 @@
 use tracing::{Instrument, Level};
 
 use super::Middleware;
-use crate::{Endpoint, Request, Response};
+use crate::{Endpoint, IntoResponse, Request, Response};
 
 /// A middleware for tracing requests and responses
 #[cfg_attr(docsrs, doc(cfg(feature = "tracing")))]
@@ -30,11 +30,10 @@ pub struct TracingImpl<E> {
 }
 
 #[async_trait::async_trait]
-impl<E> Endpoint for TracingImpl<E>
-where
-    E: Endpoint,
-{
-    async fn call(&self, req: Request) -> Response {
+impl<E: Endpoint> Endpoint for TracingImpl<E> {
+    type Output = Response;
+
+    async fn call(&self, req: Request) -> Self::Output {
         let span = tracing::span!(
             Level::INFO,
             "handle request",
@@ -44,7 +43,7 @@ where
 
         let fut = self.inner.call(req);
         async move {
-            let resp = fut.await;
+            let resp = fut.await.into_response();
 
             if resp.status().is_success() {
                 ::tracing::info!(status = %resp.status(), "send response");
