@@ -16,6 +16,7 @@ mod redirect;
 pub mod sse;
 #[cfg(feature = "tempfile")]
 mod tempfile;
+mod template;
 #[cfg(feature = "typed-headers")]
 mod typed_header;
 #[cfg(feature = "websocket")]
@@ -46,6 +47,7 @@ pub use multipart::{Field, Multipart};
 pub use path::Path;
 pub use query::Query;
 pub use redirect::Redirect;
+pub use template::Template;
 #[cfg(feature = "typed-headers")]
 #[cfg_attr(docsrs, doc(cfg(feature = "typed-headers")))]
 pub use typed_header::TypedHeader;
@@ -214,7 +216,8 @@ impl RequestBody {
 ///     assert_eq!(token.0, "token123");
 /// }
 ///
-/// let app = route().at("/", index);
+/// let mut app = route();
+/// app.at("/").get(index);
 ///
 /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
 /// let _ = index
